EBernhardson has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/180043

Change subject: Don't pass along schema as an EventLogging argument
......................................................................

Don't pass along schema as an EventLogging argument

Flow's eventlogging tracking code needs to hold onto this schema
value for internal processing, but not pass it along to EL.  Simple
change should be easy to review.

Fixes T78577

Bug: T78577
Change-Id: I5b6c7c40be61a536b9c8b18ed978e6ce25303244
(cherry picked from commit 3e3059ec1de383fd2bbe700d69837deee8fc38bf)
---
M modules/engine/components/common/flow-component-events.js
1 file changed, 8 insertions(+), 4 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/Flow 
refs/changes/43/180043/1

diff --git a/modules/engine/components/common/flow-component-events.js 
b/modules/engine/components/common/flow-component-events.js
index f5edc41..9e6c82a 100644
--- a/modules/engine/components/common/flow-component-events.js
+++ b/modules/engine/components/common/flow-component-events.js
@@ -547,9 +547,16 @@
                        eventInstance = {},
                        key, value;
 
                // Fetch loggable data: everything prefixed flowEventlog
                for ( key in data ) {
                        if ( key.indexOf( 'flowEventlog' ) === 0 ) {
+                               // @todo Either the data or this config should 
have separate prefixes,
+                               // it shouldn't be shared and then handled here.
+                               if ( key === 'flowEventlogForward' || key === 
'flowEventlogSchema' ) {
+                                       continue;
+                               }
+
                                // Strips "flowEventlog" and lowercases first 
char after that
                                value = data[key];
                                key = key.substr( 12, 1 ).toLowerCase() + 
key.substr( 13 );
@@ -557,9 +564,6 @@
                                eventInstance[key] = value;
                        }
                }
-
-               // Forward is not loggable data!
-               delete eventInstance.forward;
 
                // Log the event
                eventInstance = component.logEvent( data.flowEventlogSchema, 
@@ -547,9 +547,16 @@
                        key, value;
 
-               // Fetch loggable data: everything prefixed flowEventlog
+               // Fetch loggable data: everything prefixed flowEventlog except
+               // flowEventLogForward and flowEventLogSchema
                for ( key in data ) {
                        if ( key.indexOf( 'flowEventlog' ) === 0 ) {
eventInstance );

-- 
To view, visit https://gerrit.wikimedia.org/r/180043
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I5b6c7c40be61a536b9c8b18ed978e6ce25303244
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/Flow
Gerrit-Branch: wmf/1.25wmf12
Gerrit-Owner: EBernhardson <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to